SDL: Renamed testgamepad to testcontroller

From ca492dff185670a307503a1023e742a824e003dc Mon Sep 17 00:00:00 2001
From: Sam Lantinga <[EMAIL REDACTED]>
Date: Tue, 11 Jul 2023 14:21:35 -0700
Subject: [PATCH] Renamed testgamepad to testcontroller

The program does more than just test gamepads, and will eventually map them as well.
---
 VisualC-GDK/SDL.sln                            |  2 +-
 .../PackageLayout.xml                          |  2 +-
 .../testcontroller.vcxproj}                    | 18 +++++++++---------
 .../testcontroller.vcxproj.filters}            |  4 ++--
 .../wingdk/MicrosoftGame.config                |  8 ++++----
 .../xboxone/MicrosoftGame.config               |  8 ++++----
 .../xboxseries/MicrosoftGame.config            |  8 ++++----
 VisualC/SDL.sln                                |  2 +-
 .../testcontroller.vcxproj}                    | 14 +++++++-------
 test/CMakeLists.txt                            |  2 +-
 test/{testgamepad.c => testcontroller.c}       |  6 +++---
 11 files changed, 37 insertions(+), 37 deletions(-)
 rename VisualC-GDK/tests/{testgamepad => testcontroller}/PackageLayout.xml (81%)
 rename VisualC-GDK/tests/{testgamepad/testgamepad.vcxproj => testcontroller/testcontroller.vcxproj} (96%)
 rename VisualC-GDK/tests/{testgamepad/testgamepad.vcxproj.filters => testcontroller/testcontroller.vcxproj.filters} (94%)
 rename VisualC-GDK/tests/{testgamepad => testcontroller}/wingdk/MicrosoftGame.config (85%)
 rename VisualC-GDK/tests/{testgamepad => testcontroller}/xboxone/MicrosoftGame.config (84%)
 rename VisualC-GDK/tests/{testgamepad => testcontroller}/xboxseries/MicrosoftGame.config (84%)
 rename VisualC/tests/{testgamepad/testgamepad.vcxproj => testcontroller/testcontroller.vcxproj} (95%)
 rename test/{testgamepad.c => testcontroller.c} (99%)

diff --git a/VisualC-GDK/SDL.sln b/VisualC-GDK/SDL.sln
index 5eef5d91bd36..2cdfa0bd8476 100644
--- a/VisualC-GDK/SDL.sln
+++ b/VisualC-GDK/SDL.sln
@@ -10,7 +10,7 @@ Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "testsprite", "tests\testspr
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "SDL3_test", "SDL_test\SDL_test.vcxproj", "{DA956FD3-E143-46F2-9FE5-C77BEBC56B1A}"
 EndProject
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "testgamepad", "tests\testgamepad\testgamepad.vcxproj", "{55812185-D13C-4022-9C81-32E0F4A08305}"
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "testcontroller", "tests\testcontroller\testcontroller.vcxproj", "{55812185-D13C-4022-9C81-32E0F4A08305}"
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "testgdk", "tests\testgdk\testgdk.vcxproj", "{1C9A3F71-35A5-4C56-B292-F4375B3C3649}"
 EndProject
diff --git a/VisualC-GDK/tests/testgamepad/PackageLayout.xml b/VisualC-GDK/tests/testcontroller/PackageLayout.xml
similarity index 81%
rename from VisualC-GDK/tests/testgamepad/PackageLayout.xml
rename to VisualC-GDK/tests/testcontroller/PackageLayout.xml
index 272543b061d2..2fc9a762a95e 100644
--- a/VisualC-GDK/tests/testgamepad/PackageLayout.xml
+++ b/VisualC-GDK/tests/testcontroller/PackageLayout.xml
@@ -1,6 +1,6 @@
 <Package>
   <Chunk Id="1000" Marker="Launch">
-    <FileGroup DestinationPath="." SourcePath="." Include="testgamepad.exe" />
+    <FileGroup DestinationPath="." SourcePath="." Include="testcontroller.exe" />
     <FileGroup DestinationPath="." SourcePath="." Include="MicrosoftGame.config" />
     <FileGroup DestinationPath="." SourcePath="." Include="*.bmp" />
     <FileGroup DestinationPath="." SourcePath="." Include="*.png" />
diff --git a/VisualC-GDK/tests/testgamepad/testgamepad.vcxproj b/VisualC-GDK/tests/testcontroller/testcontroller.vcxproj
similarity index 96%
rename from VisualC-GDK/tests/testgamepad/testgamepad.vcxproj
rename to VisualC-GDK/tests/testcontroller/testcontroller.vcxproj
index bb3c52e22f64..3f0156166eff 100644
--- a/VisualC-GDK/tests/testgamepad/testgamepad.vcxproj
+++ b/VisualC-GDK/tests/testcontroller/testcontroller.vcxproj
@@ -28,7 +28,7 @@
   </ItemGroup>
   <PropertyGroup Label="Globals">
     <ProjectGuid>{55812185-D13C-4022-9C81-32E0F4A08305}</ProjectGuid>
-    <RootNamespace>testgamepad</RootNamespace>
+    <RootNamespace>testcontroller</RootNamespace>
     <VisualStudioVersion Condition="'$(VisualStudioVersion)' == ''">10.0</VisualStudioVersion>
   </PropertyGroup>
   <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
@@ -124,7 +124,7 @@
       <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TypeLibraryName>.\Release/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Release/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <AdditionalIncludeDirectories>$(SolutionDir)/../include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
@@ -147,7 +147,7 @@
       <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TypeLibraryName>.\Release/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Release/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <AdditionalIncludeDirectories>$(SolutionDir)/../include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
@@ -170,7 +170,7 @@
       <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TypeLibraryName>.\Release/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Release/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <AdditionalIncludeDirectories>$(SolutionDir)/../include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
@@ -193,7 +193,7 @@
       <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TypeLibraryName>.\Debug/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Debug/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <Optimization>Disabled</Optimization>
@@ -219,7 +219,7 @@
       <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TypeLibraryName>.\Debug/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Debug/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <Optimization>Disabled</Optimization>
@@ -245,7 +245,7 @@
       <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TypeLibraryName>.\Debug/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Debug/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <Optimization>Disabled</Optimization>
@@ -276,7 +276,7 @@
   </ItemGroup>
   <ItemGroup>
     <ClCompile Include="..\..\..\test\gamepadutils.c" />
-    <ClCompile Include="..\..\..\test\testgamepad.c" />
+    <ClCompile Include="..\..\..\test\testcontroller.c" />
     <ClCompile Include="..\..\..\test\testutils.c" />
   </ItemGroup>
   <ItemGroup>
@@ -330,4 +330,4 @@
   <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
   <ImportGroup Label="ExtensionTargets">
   </ImportGroup>
-</Project>
\ No newline at end of file
+</Project>
diff --git a/VisualC-GDK/tests/testgamepad/testgamepad.vcxproj.filters b/VisualC-GDK/tests/testcontroller/testcontroller.vcxproj.filters
similarity index 94%
rename from VisualC-GDK/tests/testgamepad/testgamepad.vcxproj.filters
rename to VisualC-GDK/tests/testcontroller/testcontroller.vcxproj.filters
index a5de19eb3b88..e4e2413ef87d 100644
--- a/VisualC-GDK/tests/testgamepad/testgamepad.vcxproj.filters
+++ b/VisualC-GDK/tests/testcontroller/testcontroller.vcxproj.filters
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="utf-8"?>
 <Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
   <ItemGroup>
-    <ClCompile Include="..\..\..\test\testgamepad.c" />
+    <ClCompile Include="..\..\..\test\testcontroller.c" />
     <ClCompile Include="..\..\..\test\testutils.c" />
     <ClCompile Include="..\..\..\test\gamepadutils.c" />
   </ItemGroup>
@@ -49,4 +49,4 @@
       <UniqueIdentifier>{e704dcb9-c83c-4c94-a139-b0f3e3f428f2}</UniqueIdentifier>
     </Filter>
   </ItemGroup>
-</Project>
\ No newline at end of file
+</Project>
diff --git a/VisualC-GDK/tests/testgamepad/wingdk/MicrosoftGame.config b/VisualC-GDK/tests/testcontroller/wingdk/MicrosoftGame.config
similarity index 85%
rename from VisualC-GDK/tests/testgamepad/wingdk/MicrosoftGame.config
rename to VisualC-GDK/tests/testcontroller/wingdk/MicrosoftGame.config
index 45adb2682bbd..162624a41063 100644
--- a/VisualC-GDK/tests/testgamepad/wingdk/MicrosoftGame.config
+++ b/VisualC-GDK/tests/testcontroller/wingdk/MicrosoftGame.config
@@ -7,7 +7,7 @@
 		Publisher="CN=Publisher"/>
 
 	<ExecutableList>
-		<Executable Name="testgamepad.exe"
+		<Executable Name="testcontroller.exe"
 					TargetDeviceFamily="PC"
 					Id="Game" />
 	</ExecutableList>
@@ -22,13 +22,13 @@
 	<MSAAppId>PleaseChangeMe</MSAAppId>
 	<TitleId>FFFFFFFF</TitleId>
 
-	<ShellVisuals DefaultDisplayName="testgamepad"
+	<ShellVisuals DefaultDisplayName="testcontroller"
 					PublisherDisplayName="SDL"
 					Square480x480Logo="Logo480x480.png"
 					Square150x150Logo="Logo150x150.png"
 					Square44x44Logo="Logo44x44.png"
-					Description="testgamepad"
+					Description="testcontroller"
 					ForegroundText="light"
 					BackgroundColor="#000000"
 					StoreLogo="Logo100x100.png"/>
-</Game>
\ No newline at end of file
+</Game>
diff --git a/VisualC-GDK/tests/testgamepad/xboxone/MicrosoftGame.config b/VisualC-GDK/tests/testcontroller/xboxone/MicrosoftGame.config
similarity index 84%
rename from VisualC-GDK/tests/testgamepad/xboxone/MicrosoftGame.config
rename to VisualC-GDK/tests/testcontroller/xboxone/MicrosoftGame.config
index f33e3779e5f8..9d908c90b098 100644
--- a/VisualC-GDK/tests/testgamepad/xboxone/MicrosoftGame.config
+++ b/VisualC-GDK/tests/testcontroller/xboxone/MicrosoftGame.config
@@ -7,7 +7,7 @@
 		Publisher="CN=Publisher"/>
 
 	<ExecutableList>
-		<Executable Name="testgamepad.exe"
+		<Executable Name="testcontroller.exe"
 					TargetDeviceFamily="XboxOne"
 					Id="Game" />
 	</ExecutableList>
@@ -16,14 +16,14 @@
 	<MSAAppId>PleaseChangeMe</MSAAppId>
 	<TitleId>FFFFFFFF</TitleId>
 
-	<ShellVisuals DefaultDisplayName="testgamepad"
+	<ShellVisuals DefaultDisplayName="testcontroller"
 					PublisherDisplayName="SDL"
 					Square480x480Logo="Logo480x480.png"
 					Square150x150Logo="Logo150x150.png"
 					Square44x44Logo="Logo44x44.png"
 					SplashScreenImage="SplashScreenImage.png"
-					Description="testgamepad"
+					Description="testcontroller"
 					ForegroundText="light"
 					BackgroundColor="#000000"
 					StoreLogo="Logo100x100.png"/>
-</Game>
\ No newline at end of file
+</Game>
diff --git a/VisualC-GDK/tests/testgamepad/xboxseries/MicrosoftGame.config b/VisualC-GDK/tests/testcontroller/xboxseries/MicrosoftGame.config
similarity index 84%
rename from VisualC-GDK/tests/testgamepad/xboxseries/MicrosoftGame.config
rename to VisualC-GDK/tests/testcontroller/xboxseries/MicrosoftGame.config
index 5fa45d436c9d..6d1829b76d79 100644
--- a/VisualC-GDK/tests/testgamepad/xboxseries/MicrosoftGame.config
+++ b/VisualC-GDK/tests/testcontroller/xboxseries/MicrosoftGame.config
@@ -7,7 +7,7 @@
 		Publisher="CN=Publisher"/>
 
 	<ExecutableList>
-		<Executable Name="testgamepad.exe"
+		<Executable Name="testcontroller.exe"
 					TargetDeviceFamily="Scarlett"
 					Id="Game" />
 	</ExecutableList>
@@ -16,14 +16,14 @@
 	<MSAAppId>PleaseChangeMe</MSAAppId>
 	<TitleId>FFFFFFFF</TitleId>
 
-	<ShellVisuals DefaultDisplayName="testgamepad"
+	<ShellVisuals DefaultDisplayName="testcontroller"
 					PublisherDisplayName="SDL"
 					Square480x480Logo="Logo480x480.png"
 					Square150x150Logo="Logo150x150.png"
 					Square44x44Logo="Logo44x44.png"
 					SplashScreenImage="SplashScreenImage.png"
-					Description="testgamepad"
+					Description="testcontroller"
 					ForegroundText="light"
 					BackgroundColor="#000000"
 					StoreLogo="Logo100x100.png"/>
-</Game>
\ No newline at end of file
+</Game>
diff --git a/VisualC/SDL.sln b/VisualC/SDL.sln
index 5c6580cec1fb..66403e16ff65 100644
--- a/VisualC/SDL.sln
+++ b/VisualC/SDL.sln
@@ -36,7 +36,7 @@ Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "testsprite", "tests\testspr
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "SDL3_test", "SDL_test\SDL_test.vcxproj", "{DA956FD3-E143-46F2-9FE5-C77BEBC56B1A}"
 EndProject
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "testgamepad", "tests\testgamepad\testgamepad.vcxproj", "{55812185-D13C-4022-9C81-32E0F4A08305}"
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "testcontroller", "tests\testcontroller\testcontroller.vcxproj", "{55812185-D13C-4022-9C81-32E0F4A08305}"
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "testgles2", "tests\testgles2\testgles2.vcxproj", "{E9558DFE-1961-4DD4-B09B-DD0EEFD5C315}"
 EndProject
diff --git a/VisualC/tests/testgamepad/testgamepad.vcxproj b/VisualC/tests/testcontroller/testcontroller.vcxproj
similarity index 95%
rename from VisualC/tests/testgamepad/testgamepad.vcxproj
rename to VisualC/tests/testcontroller/testcontroller.vcxproj
index 73890d630d70..5bdcc3b21b37 100644
--- a/VisualC/tests/testgamepad/testgamepad.vcxproj
+++ b/VisualC/tests/testcontroller/testcontroller.vcxproj
@@ -20,7 +20,7 @@
   </ItemGroup>
   <PropertyGroup Label="Globals">
     <ProjectGuid>{55812185-D13C-4022-9C81-32E0F4A08305}</ProjectGuid>
-    <RootNamespace>testgamepad</RootNamespace>
+    <RootNamespace>testcontroller</RootNamespace>
     <VisualStudioVersion Condition="'$(VisualStudioVersion)' == ''">10.0</VisualStudioVersion>
   </PropertyGroup>
   <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
@@ -89,7 +89,7 @@
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
       <TargetEnvironment>Win32</TargetEnvironment>
-      <TypeLibraryName>.\Release/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Release/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <AdditionalIncludeDirectories>$(SolutionDir)/../include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
@@ -112,7 +112,7 @@
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
       <TargetEnvironment>X64</TargetEnvironment>
-      <TypeLibraryName>.\Release/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Release/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <AdditionalIncludeDirectories>$(SolutionDir)/../include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
@@ -135,7 +135,7 @@
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
       <TargetEnvironment>Win32</TargetEnvironment>
-      <TypeLibraryName>.\Debug/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Debug/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <Optimization>Disabled</Optimization>
@@ -161,7 +161,7 @@
       <MkTypLibCompatible>true</MkTypLibCompatible>
       <SuppressStartupBanner>true</SuppressStartupBanner>
       <TargetEnvironment>X64</TargetEnvironment>
-      <TypeLibraryName>.\Debug/testgamepad.tlb</TypeLibraryName>
+      <TypeLibraryName>.\Debug/testcontroller.tlb</TypeLibraryName>
     </Midl>
     <ClCompile>
       <Optimization>Disabled</Optimization>
@@ -197,10 +197,10 @@
   </ItemGroup>
   <ItemGroup>
     <ClCompile Include="..\..\..\test\gamepadutils.c" />
-    <ClCompile Include="..\..\..\test\testgamepad.c" />
+    <ClCompile Include="..\..\..\test\testcontroller.c" />
     <ClCompile Include="..\..\..\test\testutils.c" />
   </ItemGroup>
   <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
   <ImportGroup Label="ExtensionTargets">
   </ImportGroup>
-</Project>
\ No newline at end of file
+</Project>
diff --git a/test/CMakeLists.txt b/test/CMakeLists.txt
index 5d903493650f..77b49f0fd4e4 100644
--- a/test/CMakeLists.txt
+++ b/test/CMakeLists.txt
@@ -209,7 +209,7 @@ if(SDL3_TESTS_SUBPROJECT)
 endif()
 
 add_sdl_test_executable(testfile NONINTERACTIVE SOURCES testfile.c)
-add_sdl_test_executable(testgamepad TESTUTILS SOURCES testgamepad.c gamepadutils.c)
+add_sdl_test_executable(testcontroller TESTUTILS SOURCES testcontroller.c gamepadutils.c)
 add_sdl_test_executable(testgeometry TESTUTILS SOURCES testgeometry.c)
 add_sdl_test_executable(testgl SOURCES testgl.c)
 add_sdl_test_executable(testgles SOURCES testgles.c)
diff --git a/test/testgamepad.c b/test/testcontroller.c
similarity index 99%
rename from test/testgamepad.c
rename to test/testcontroller.c
index 585712d812a1..099f06ad3fea 100644
--- a/test/testgamepad.c
+++ b/test/testcontroller.c
@@ -10,7 +10,7 @@
   freely.
 */
 
 /* Simple program to test the SDL gamepad routines */
 
 #include <SDL3/SDL.h>
 #include <SDL3/SDL_main.h>
@@ -46,7 +46,7 @@ static const char *power_level_strings[] = {
 };
 SDL_COMPILE_TIME_ASSERT(power_level_strings, SDL_arraysize(power_level_strings) == SDL_JOYSTICK_POWER_MAX + 1);
 
-typedef struct 
+typedef struct
 {
     SDL_JoystickID id;
     SDL_Joystick *joystick;
@@ -931,7 +931,7 @@ int main(int argc, char *argv[])
     }
     screen_width = (int)SDL_ceilf(SCREEN_WIDTH * content_scale);
     screen_height = (int)SDL_ceilf(SCREEN_HEIGHT * content_scale);
-    window = SDL_CreateWindow("Gamepad Test", screen_width, screen_height, 0);
+    window = SDL_CreateWindow("SDL Controller Test", screen_width, screen_height, 0);
     if (window == NULL) {
         SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Couldn't create window: %s\n", SDL_GetError());
         return 2;
@@ -10,7 +10,7 @@
 */
 
-/* Simple program to test the SDL gamepad routines */
+/* Simple program to test the SDL controller routines */
 
 #include <SDL3/SDL.h>